@@ -1,5 +1,5 @@
 package Telegram::Bot;
-$Telegram::Bot::VERSION = '0.020';
+$Telegram::Bot::VERSION = '0.021';
 use strict;
 use warnings;
 
@@ -20,7 +20,7 @@ Telegram::Bot - A base class to make your very own Telegram bot
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -34,16 +34,6 @@ Creating a bot is easy:
 
     has token => 'YOURTOKENHERE';
 
-    # is this a message we'd like to respond to?
-    sub _hello_for_me {
-      my ($self, $msg) = @_;
-      # look for the word 'hello' with or without a leading slash
-      if ($msg->text =~ m{/?hello}i) {
-        return 1;
-      }
-      return 0;
-    }
-
     # send a polite reply, to either a group or a single user,
     # depending on where we were addressed from
     sub _be_polite {
@@ -81,6 +71,11 @@ and you've got yourself a stew, baby! Or a bot, anyway.
 Note that for the bot to see messages that do not start with a leading '/', you will need to use
 the C<'/setprivacy'> command on Telegram's C<@botfather> interface to change the privacy settings.
 
+=head1 EXAMPLES
+
+This distribution's C<ex/> directory contains some complete examples that may be
+instructive to look at.
+
 =head1 AUTHOR
 
 Justin Hawkins <justin@eatmorecode.com>
