@@ -1,5 +1,5 @@
 package Telegram::Bot::Brain;
-$Telegram::Bot::Brain::VERSION = '0.020';
+$Telegram::Bot::Brain::VERSION = '0.021';
 # ABSTRACT: A base class to make your very own Telegram bot
 
 
@@ -77,7 +77,7 @@ sub think {
 
 sub getMe {
   my $self = shift;
-  my $token = $self->token;
+  my $token = $self->token || croak "no token?";
 
   my $url = "https://api.telegram.org/bot${token}/getMe";
   my $api_response = $self->_post_request($url);
@@ -114,7 +114,7 @@ sub sendMessage {
     $send_args->{reply_markup} = $reply_markup;
   }
 
-  my $token = $self->token;
+  my $token = $self->token || croak "no token?";
   my $url = "https://api.telegram.org/bot${token}/sendMessage";
   my $api_response = $self->_post_request($url, $send_args);
 
@@ -138,7 +138,7 @@ sub forwardMessage {
   # these are optional, send if they are supplied
   $send_args->{disable_notification} = $args->{disable_notification} if exists $args->{disable_notification};
 
-  my $token = $self->token;
+  my $token = $self->token || croak "no token?";
   my $url = "https://api.telegram.org/bot${token}/forwardMessage";
   my $api_response = $self->_post_request($url, $send_args);
 
@@ -166,7 +166,7 @@ sub sendPhoto {
     $send_args->{photo} = $args->{photo};
   }
 
-  my $token = $self->token;
+  my $token = $self->token || croak "no token?";
   my $url = "https://api.telegram.org/bot${token}/sendPhoto";
   my $api_response = $self->_post_request($url, $send_args);
 
@@ -256,7 +256,7 @@ Telegram::Bot::Brain - A base class to make your very own Telegram bot
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
